@@ -8,13 +8,13 @@ from .drawer import get_token, get_taskId, get_img
 from .limiter import limiter
 from .config import wenxin_config
 
-drawer = on_command("画画", aliases={'画画帮助', '油画', '水彩画', '卡通画', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
+drawer = on_command("画画", aliases={'画画帮助', '古风' , '油画', '水彩画', '卡通画', '二次元', '浮世绘', '蒸汽波艺术', 'low poly', '像素风格', '概念艺术', '未来主义', '赛博朋克', '写实风格', '洛丽塔风格', '巴洛克风格', '超现实主义'}, priority=5, block=True)
 
 @drawer.handle()
 async def _(matcher: Matcher, event: GroupMessageEvent, command = RawCommand(), args = CommandArg()):
     # 判断是否触发帮助 或 绘画主题任务描述为空
     if  command == '画画帮助' or str(args).strip() == '': 
-        help_msg = '当前支持油画、水彩画、卡通画、粉笔画、儿童画、蜡笔画\n主要擅长风景写意画,请尽量给定“比较明确的意象”\n如: 油画 江上落日与晚霞'
+        help_msg = '当前支持古风、油画、水彩画、卡通画、二次元、浮世绘、蒸汽波艺术、low poly、像素风格、概念艺术、未来主义、赛博朋克、写实风格、洛丽塔风格、巴洛克风格、超现实主义\n主要擅长风景写意画,请尽量给定“比较明确的意象”\n如: 油画 江上落日与晚霞'
         await matcher.finish(help_msg)
         return
     
@@ -23,13 +23,13 @@ async def _(matcher: Matcher, event: GroupMessageEvent, command = RawCommand(),
     managers = wenxin_config.wenxin_manager_list # 管理员列表(不触发冷却时间限制)
     if not limiter.check(user_id):
         left_time = limiter.left_time(user_id)
-        await matcher.finish(f'咦，人类，你刚画了一次唉。需要等待{left_time}秒再找俺画画！')
+        await matcher.finish(f'咦，人类，你刚画了一次唉。需要等待{left_time}秒再找俺画画！冷却期间可临时到网页（https://wenxin.baidu.com/moduleApi/ernieVilg?from=baicai）进行体验哦')
         return 
     
     # 启动画画任务
     command_str = str(command)
     style = '油画' # 绘画时style默认为油画
-    style_list = ['油画', '水彩', '卡通', '粉笔画', '儿童画', '蜡笔画']
+    style_list = ['古风' , '油画', '水彩画', '卡通画', '二次元', '浮世绘', '蒸汽波艺术', 'low poly', '像素风格', '概念艺术', '未来主义', '赛博朋克', '写实风格', '洛丽塔风格', '巴洛克风格', '超现实主义']
     for keyword in style_list:
         if keyword in command_str:
             style = keyword
@@ -46,7 +46,7 @@ async def _(matcher: Matcher, event: GroupMessageEvent, command = RawCommand(),
         
         if not str(user_id) in managers: 
             limiter.start_cd(user_id) # 启动冷却时间限制
-        await asyncio.sleep(70) # 模型画画大概要70秒，等待一会儿
+        await asyncio.sleep(30) # 模型画画大概要30秒，等待一会儿
         images = await get_img(access_token, taskId)
         if images == None:
             await matcher.finish(f'无法绘制主题为“{text}”的{style}!')
